@@ -1,3 +1,7 @@
+__author__  = "Great Tomorrow(gr82morozr@gmail.com)"
+__license__ = "MIT"
+__version__ = "0.0.84"
+
 from .fs_tools        import  *
 from .img_tools       import  *
 from .net_tools       import  *
@@ -11,3 +15,7 @@ from .html_tools      import  *
 from .mail_tools      import  *
 from .dict_tools      import  *
 from .media_tools     import  *
+from .gdrive_tools    import  *
+from .daemon_tools    import  *
+from .helper          import  *
+
