@@ -21,7 +21,7 @@ def rm_folder(folder_name, empty_only=False):
     file_list = get_files(folder = folder_name, type='file')
     dir_list  = get_files(folder = folder_name, type='dir')
     for d in dir_list :
-      if is_file_exists(d) :
+      if file_exists(d) :
         d_empty = True
         for f in file_list :      
           if f.find(d) == 0 :
@@ -32,15 +32,18 @@ def rm_folder(folder_name, empty_only=False):
         
     
 def mk_folder(folder_name) :
-  if is_file_exists(folder_name) == False :
+  if file_exists(folder_name) == False :
     os.makedirs(folder_name, exist_ok=True)
 
 def get_file_folder(file_path) :
-  return os.path.dirname (file_path)
+  return os.path.dirname(file_path)
   
+def get_file_name(file_path) :
+  return os.path.basename(file_path)
+
   
 def clean_folder(folder_name):
-  if is_file_exists(folder_name) :
+  if file_exists(folder_name) :
     for the_file in os.listdir(folder_name):
       file_path = os.path.join(folder_name, the_file)
       if   os.path.isfile(file_path) : rm_file(file_path)
@@ -48,11 +51,17 @@ def clean_folder(folder_name):
   else:
     mk_folder (folder_name)
   
-def is_file_exists(file_name):
+def file_exists(file_name):
   return os.path.exists(file_name)
+
+
+
+def exists(file_name):
+  return file_exists(file_name)
+
   
 def copy_file(src_file,dest_file):
-  if is_file_exists(src_file) :  
+  if file_exists(src_file) :  
     mk_folder(get_file_folder(dest_file))
     copyfile(src_file,dest_file)    
   
@@ -62,7 +71,7 @@ def rm_file(file_name) :
     
 def write_file(file_name, text, mode='w', is_new = False):
   file_folder = get_file_folder(file_name)
-  if is_file_exists(file_folder) == False: mk_folder(file_folder)
+  if file_exists(file_folder) == False: mk_folder(file_folder)
     
   if is_new == True: rm_file(file_name)
   with codecs.open(file_name, mode, 'utf8') as fh:
@@ -85,6 +94,8 @@ def get_md5(file_name) :
     hasher.update(buf)
   return (hasher.hexdigest())
 
+def get_md5_txt(text) :  
+  return hashlib.md5(text.encode('utf-8')).hexdigest()
   
 def is_file (file) :
   return os.path.isfile(file) 
@@ -93,7 +104,7 @@ def is_folder (file) :
   return os.path.isdir(file) 
   
 def check_type(full_path):
-  if is_file_exists(full_path) : 
+  if file_exists(full_path) : 
     if is_file(full_path) : 
       return 'file'
     elif is_folder(full_path) :  
@@ -117,7 +128,7 @@ def get_files(folder, ext='', recursive=True, type='all') :
   return files
 
 def get_file_info(file_name) :
-  if is_file_exists(file_name):
+  if file_exists(file_name):
     st = os.stat(file_name)
     return { "file_name": file_name, "size" : int(st[ST_SIZE]), "access_time" : st[ST_ATIME] }
   else:
@@ -385,8 +396,8 @@ def replace_text_files(replace_keys, files, casesesitive=True):
 if __name__ == "__main__":
   #print (len( get_files (folder="R:/", type='file')))
   
-  #for f in gen_files (folder="R:/", type='file'):
-  #  print (f)
+  for f in gen_files (folder="Y:/important", type='file'):
+    print (f)
   
 
   #print (base64_encode(input_file="R:/panda.jpg",output_file="R:/panda.jpg.b64", output="text"))
